THIS IS A WORK OF ART BY JAYANT NARAYAN FOR P.S. RANA AS TOPSIS ASSIGNMENT 4 
TO INSTALL THIS INTO PC:
pip install Topsis-Jayant-401903026==0.0.2

TO RUN IN CMD:

python <program.py> <InputDataFile> <Weights> <Impacts> <ResultFileName>

